@@ -46,7 +46,7 @@ class Dominio_class(Thread):
         self.listaOrd = list(range(self.limite))
         self.listaJug =  list(range(self.limite))
         #self.sUrlRutaMaemo = ""
-        self.sUrlRutaMaemo = "/opt/simonKM/"
+        self.sUrlRutaMaemo = "/opt/simonkm/"
         self.soundRojo = self.sUrlRutaMaemo + 'sounds/simonSound1.wav'
         self.soundVerde = self.sUrlRutaMaemo + 'sounds/simonSound2.wav'
         self.soundAzul = self.sUrlRutaMaemo + 'sounds/simonSound3.wav'
